@@ -171,7 +171,7 @@
 
 	NomFichier  <- "go_daily-termdb-tables.tar.gz"
 
-	download.file(paste ("http://godatabase-archive.stanford.edu/latest-termdb/", NomFichier,sep = ""),paste (getwd(),"/go_daily-termdb-tables.tar.gz",sep=""),mode="wb")
+	download.file(paste ("http://archive.geneontology.org/latest-termdb/", NomFichier,sep = ""),paste (getwd(),"/go_daily-termdb-tables.tar.gz",sep=""),mode="wb")
 
 	system("gunzip go_daily-termdb-tables.tar.gz")
 	system("tar -xf go_daily-termdb-tables.tar")
@@ -415,7 +415,7 @@ annotations <- function(cust.specs=NULL){
 	annot.base <<- list(NULL)
 
 	if(is.null(species)){
-		species <<- cbind(c("hsa","mmu","rno","sce"),c("9606","10090","10116","4932"))
+		species <<- cbind(c("hsa","mmu","rno","sce","gga"),c("9606","10090","10116","4932","9031"))
 		colnames(species) <<- c("name","taxid")
 		rownames(species) <<- species[,"taxid"]
 	}
